# pyscpi

[![PyPI version](https://badge.fury.io/py/pyscpi.svg)](https://badge.fury.io/py/pyscpi)

A Python library for communicating with SCPI devices and a helper library for communicating with the Keysight's [Smart Bench Essentials](https://www.keysight.com/us/en/cmp/2021/keysight-smart-bench-essentials-test-instruments.html) educational equipment. It can be used with Keysight's IOLibrary and driverless using TCP/IP socket communication.

## Using PyVisa

you need to install Keysight's IOLibrary and PyVisa

```bash

```

## Using Socket (Driverless)

You don't need to install any drivers or libraries. You can use the socket library to communicate with the device. However, you need to connect the instrument to the same network as your computer either using a direct ethernet cable or a switch/router. Please notice if you are not using a router then you have may need to set the instrument's IP address manually. Further information can be found in the [here]().


## Connecting instrument to your computer

There are several ways to connect the instrument to your computer. You can use any of the following methods:

### USB

### Direct Ethernet Cable

### Switch

### Router

 
